==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-manifest/nifi-extension-manifest-model/src/main/java/org/apache/nifi/extension/manifest/DefaultSchedule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.extension.manifest;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;

@ApiModel
@XmlAccessorType(XmlAccessType.FIELD)
public class DefaultSchedule {

    private String strategy;
    private String period;
    private String concurrentTasks;

    @ApiModelProperty("The default scheduling strategy")
    public String getStrategy() {
        return strategy;
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    @ApiModelProperty("The default scheduling period")
    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    @ApiModelProperty("The default concurrent tasks")
    public String getConcurrentTasks() {
        return concurrentTasks;
    }

    public void setConcurrentTasks(String concurrentTasks) {
        this.concurrentTasks = concurrentTasks;
    }

}

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-manifest/nifi-extension-manifest-model/src/main/java/org/apache/nifi/extension/manifest/DefaultSchedule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.extension.manifest;

import io.swagger.v3.oas.annotations.media.Schema;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;

@XmlAccessorType(XmlAccessType.FIELD)
public class DefaultSchedule {

    private String strategy;
    private String period;
    private String concurrentTasks;

    @Schema(description = "The default scheduling strategy")
    public String getStrategy() {
        return strategy;
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    @Schema(description = "The default scheduling period")
    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    @Schema(description = "The default concurrent tasks")
    public String getConcurrentTasks() {
        return concurrentTasks;
    }

    public void setConcurrentTasks(String concurrentTasks) {
        this.concurrentTasks = concurrentTasks;
    }

}
